@@ -4,41 +4,42 @@ data_location = os.path.join(__dir__, "data")
 src = "https://github.com/picolibc/picolibc"
 
 # Module version
-version_str = "1.7.6.post184"
-version_tuple = (1, 7, 6, 184)
+version_str = "1.7.7.post146"
+version_tuple = (1, 7, 7, 146)
 try:
     from packaging.version import Version as V
-    pversion = V("1.7.6.post184")
+    pversion = V("1.7.7.post146")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.7.6.post56"
-data_version_tuple = (1, 7, 6, 56)
+data_version_str = "1.7.7.post4"
+data_version_tuple = (1, 7, 7, 4)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.7.6.post56")
+    pdata_version = V("1.7.7.post4")
 except ImportError:
     pass
-data_git_hash = "c60f7e0c32f5cbd16757e1899fecd350ba168a78"
-data_git_describe = "1.7.6-56-gc60f7e0c3"
+data_git_hash = "579710373351530f3614389cbb1dc1f3f2085b56"
+data_git_describe = "1.7.7-4-g579710373"
 data_git_msg = """\
-commit c60f7e0c32f5cbd16757e1899fecd350ba168a78
-Author: Keith Packard <keithp@keithp.com>
-Date:   Tue May 17 16:03:10 2022 -0700
+commit 579710373351530f3614389cbb1dc1f3f2085b56
+Author: Max Behensky <maxb@twinlanes.com>
+Date:   Thu Jun 2 16:49:04 2022 -0700
 
-    .github: Add a cmake test
+    Fix issues with out of source build CMake install.
     
-    Signed-off-by: Keith Packard <keithp@keithp.com>
+    The picolibc.specs file lives in the build directory, not the source directory.
+    The picolibc.h file wasn't getting copied to the install include directory.
 
 """
 
 # Tool version info
-tool_version_str = "0.0.post128"
-tool_version_tuple = (0, 0, 128)
+tool_version_str = "0.0.post142"
+tool_version_tuple = (0, 0, 142)
 try:
     from packaging.version import Version as V
-    ptool_version = V("0.0.post128")
+    ptool_version = V("0.0.post142")
 except ImportError:
     pass
 
